@@ -1,23 +1,25 @@
 from datetime import timedelta
 from time import sleep
 
-from django.utils import timezone
 from django import db
 from django.db import transaction
+from django.utils import timezone
 
 from django_q.brokers import Broker
-from django_q.models import OrmQ
 from django_q.conf import Conf, logger
+from django_q.models import OrmQ
 
 
 def _timeout():
-    return timezone.now() - timedelta(seconds=Conf.RETRY)
+    return timezone.now() + timedelta(seconds=Conf.RETRY)
 
 
 class ORM(Broker):
     @staticmethod
-    def get_connection(list_key=Conf.PREFIX):
-        if transaction.get_autocommit():  # Only True when not in an atomic block
+    def get_connection(list_key: str = None):
+        if transaction.get_autocommit(
+            using=Conf.ORM
+        ):  # Only True when not in an atomic block
             # Make sure stale connections in the broker thread are explicitly
             #   closed before attempting DB access.
             # logger.debug("Broker thread calling close_old_connections")
@@ -26,25 +28,27 @@ class ORM(Broker):
             logger.debug("Broker in an atomic transaction")
         return OrmQ.objects.using(Conf.ORM)
 
-    def queue_size(self):
+    def queue_size(self) -> int:
         return (
             self.get_connection()
-            .filter(key=self.list_key, lock__lte=_timeout())
+            .filter(key=self.list_key, lock__lte=timezone.now())
             .count()
         )
 
-    def lock_size(self):
+    def lock_size(self) -> int:
         return (
-            self.get_connection().filter(key=self.list_key, lock__gt=_timeout()).count()
+            self.get_connection()
+            .filter(key=self.list_key, lock__gt=timezone.now())
+            .count()
         )
 
     def purge_queue(self):
         return self.get_connection().filter(key=self.list_key).delete()
 
-    def ping(self):
+    def ping(self) -> bool:
         return True
 
-    def info(self):
+    def info(self) -> str:
         if not self._info:
             self._info = f"ORM {Conf.ORM}"
         return self._info
@@ -53,14 +57,17 @@ class ORM(Broker):
         self.delete(task_id)
 
     def enqueue(self, task):
+        # list_key might be null (e.g. in a test setup) but OrmQ.key has not-null constraint
         package = self.get_connection().create(
-            key=self.list_key, payload=task, lock=_timeout()
+            key=self.list_key or Conf.CLUSTER_NAME, payload=task, lock=timezone.now()
         )
         return package.pk
 
     def dequeue(self):
-        tasks = self.get_connection().filter(key=self.list_key, lock__lt=_timeout())[
-            0 : Conf.BULK
+        tasks = self.get_connection().filter(
+            key=self.list_key, lock__lt=timezone.now()
+        )[
+            0 : Conf.BULK  # noqa: E203
         ]
         if tasks:
             task_list = []
@@ -68,10 +75,11 @@ class ORM(Broker):
                 if (
                     self.get_connection()
                     .filter(id=task.id, lock=task.lock)
-                    .update(lock=timezone.now())
+                    .update(lock=_timeout())
                 ):
                     task_list.append((task.pk, task.payload))
-                # else don't process, as another cluster has been faster than us on that task
+                # else don't process, as another cluster has been faster than us on
+                # that task
             return task_list
         # empty queue, spare the cpu
         sleep(Conf.POLL)
